<?php
    /**
     * Created by PhpStorm.
     * User: stes
     * Date: 07.05.18
     * Time: 15:14
     */
    
    namespace backend\controllers;
    
    use artbox\core\admin\actions\Create;
    use artbox\core\admin\actions\Delete;
    use artbox\core\admin\actions\Index;
    use artbox\core\admin\actions\Update;
    use artbox\core\admin\actions\View;
    use artbox\core\admin\interfaces\ControllerInterface;
    use artbox\core\admin\widgets\Form;
    use common\models\Gallery;
    use yii\filters\AccessControl;
    use yii\filters\VerbFilter;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;

    class GalleryController extends Controller implements ControllerInterface
    {
        public function behaviors()
        {
            return [
                'verbs'  => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'delete' => [ 'POST' ],
                    ],
                ],
                'access' => [
                    'class' => AccessControl::className(),
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => [ '@' ],
                        ],
                    ],
                ],
            ];
        }
        public function actions()
        {
            return [
                'index' => [
                    'class' => Index::className(),
                    'columns' => [
                        'title' => [
                            'type' => Index::ACTION_COL
                        ],
                        'sort'       => [
                            'type' => Index::POSITION_COL,
                        ],
                        'status' => [
                            'type' => Index::STATUS_COL
                        ]
                    ],
                    'model' => Gallery::className(),
                    'hasLanguage'      => true,
                    'enableMassDelete' => true,
                    'modelPrimaryKey'  => 'id',
                ],
                'create' => array_merge([ 'class' => Create::className() ], self::fieldsConfig()),
                'update' => array_merge([ 'class' => Update::className() ], self::fieldsConfig()),
                'view'   => [
                    'class'          => View::className(),
                    'model'          => Gallery::className(),
                    'hasAlias'       => false,
                    'hasGallery'     => false,
                    'languageFields' => [
                        [
                            'name' => 'title',
                            'type' => Form::STRING,
                        ]
                    ],
                    'fields'         => [
                        [
                            'name' => 'image_id',
                            'type' => Form::IMAGE,
                        ],
                    ],
                ],
                'delete' => [
                    'class' => Delete::className(),
                ],
            ];
        }
    
        public function findModel($id)
        {
            $model = Gallery::find()
                             ->with('languages')
                             ->where([ 'id' => $id ])
                             ->one();
            if ($model !== null) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }
    
        public function newModel()
        {
            return new Gallery();
        }
    
        public function deleteModel($id)
        {
            $page = Gallery::find()
                            ->with('languages')
                            ->where(
                                [
                                    'id' => $id,
                                ]
                            )
                            ->one();
        
            return $page->delete();
        }
    
        protected static function fieldsConfig()
        {
            return [
                'model'          => Gallery::className(),
                'hasAlias'       => false,
                'hasGallery'     => false,
                'languageFields' => [
                    [
                        'name' => 'title',
                        'type' => Form::STRING,
                    ],
                ],
                'fields'         => [
                    [
                        'name' => 'image_id',
                        'type' => Form::IMAGE,
                    ],
                    [
                        'name' => 'status',
                        'type' => Form::BOOL,
                    ],
                    [
                        'name' => 'sort',
                        'type' => Form::NUMBER,
                    ],
                ],
            ];
        }
    }