<?php
    /**
     * Created by PhpStorm.
     * User: stes
     * Date: 07.05.18
     * Time: 14:57
     */
    
    namespace common\models;
    
    use artbox\core\models\Image;
    use artbox\core\models\Language;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii2tech\ar\position\PositionBehavior;
    use yii2tech\ar\variation\VariationBehavior;

    class Gallery extends ActiveRecord
    {
        public function rules()
        {
            return [
                [
                    [ 'sort' ],
                    'integer',
                ],
                [
                    [ 'status' ],
                    'boolean',
                ],
                [
                   [ 'image_id' ],
                   'required'
                ]
            ];
        }
    
        public function behaviors()
        {
            return [
                'translations' => [
                    'class'                             => VariationBehavior::className(),
                    'variationsRelation'                => 'languages',
                    'defaultVariationRelation'          => 'language',
                    'variationOptionReferenceAttribute' => 'language_id',
                    'optionModelClass'                  => Language::className(),
                    'defaultVariationOptionReference'   => function () {
                        return Language::getCurrent()->id;
                    },
                    'optionQueryFilter'                 => function (ActiveQuery $query) {
                        $query->where(
                            [
                                'status' => true,
                            ]
                        );
                    },
                ],
                'positionBehavior'     => [
                    'class'             => PositionBehavior::className(),
                    'positionAttribute' => 'sort',
                ],
            ];
        }
    
        public static function tableName()
        {
            return 'gallery';
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguages()
        {
            return $this->hasMany(GalleryLang::className(), [ 'gallery_id' => 'id' ]);
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasDefaultVariationRelation();
        }
    
        public function attributeLabels()
        {
            return [
                'title'  => \Yii::t('core', 'Title'),
                'status' => \Yii::t('core', 'Status'),
                'sort'   => \Yii::t('core', 'Sort'),
                'image_id'    => \Yii::t('core', 'Image'),
            ];
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getImage()
        {
            return $this->hasOne(Image::className(), [ 'id' => 'image_id' ]);
        }
        
        
    }