<?php
    
    /**
     * @var View                      $this
     * @var string                    $content
     * @var SeoComponent              $seo
     * @var User                      $user
     * @var PageCategory[]            $pageCategories
     * @var \artbox\core\forms\Module $module ;
     */
    
    use artbox\core\components\SeoComponent;
    use artbox\core\helpers\ImageHelper;
    use artbox\core\models\Feedback;
    use artbox\core\models\PageCategory;
    use artbox\core\models\User;
    use common\models\page\Category;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use artbox\core\components\imagemanager\models\ImageManager;
    use frontend\widgets\ArtboxModalWidget;
    use frontend\widgets\LanguageWidget;
    use yii\bootstrap\Nav;
    use yii\bootstrap\Html;
    use yii\db\ActiveQuery;
    use frontend\helpers\Url;
    use yii\web\View;
    use yii\widgets\Breadcrumbs;
   
    AppAsset::register($this);
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new Feedback();
    $settings = Settings::getInstance();

    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    $pageCategories = Category::find()
                              ->with(
                                  [
                                      'language',
                                      'pages' => function (ActiveQuery $query) {
                                          $query->with('language.alias')
                                                ->where([ 'in_menu' => true ])
                                                ->orderBy([ 'sort' => SORT_ASC ]);
                                      },
                                  ]
                              )
                              ->where([ 'status' => true ])
                              ->orderBy([ 'sort' => SORT_ASC ])
                              ->all();
    $logo = null;
    if ($settings->logo) {
        $logo_img = ImageManager::findOne($settings->logo);
        if ($logo_img) {
            $logo = $logo_img->getImagePathPrivate() ?? $logo;
        }
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'description',
            'content' => $seo->desc,
        ]
    );
    $module = \Yii::$app->getModule('feedback');
?>

<?php $this->beginPage() ?>
  <!DOCTYPE html>
  <html lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width, initial-scale=1">
        <?= Html::csrfMetaTags() ?>
      <title><?= Html::encode($seo->title) ?></title>
        <?php $this->head() ?>
    </head>
    <body>
        <?php $this->beginBody() ?>
      <!-- Google Analytics -->
        <?php if (!empty($settings->ga_code)) { ?>
          <script>
              (function(i, s, o, g, r, a, m) {
                  i[ 'GoogleAnalyticsObject' ] = r;
                  i[ r ] = i[ r ] || function() {
                      (i[ r ].q = i[ r ].q || []).push(arguments)
                  }, i[ r ].l = 1 * new Date();
                  a = s.createElement(o), m = s.getElementsByTagName(o)[ 0 ];
                  a.async = 1;
                  a.src = g;
                  m.parentNode.insertBefore(a, m)
              })(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga');

              ga('create', '<?=$settings->ga_code?>', 'auto');
              ga('send', 'pageview');
          
          </script>
        <?php } ?>
      <div id="all">
        <header>
          <!-- *** TOP ***
_________________________________________________________ -->
          <div id="top">
            <div class="container">
              <div class="row">
                <div class="col-xs-5 contact">
                  <p class="hidden-sm hidden-xs">
                      <?php
                          if (!empty($settings->phone)) {
                              echo \Yii::t('app', 'Contact us on ');
                              echo Html::a($settings->phone, "tel: {$settings->phone}");
                              if (!empty($settings->email)) {
                                  echo \Yii::t('app', ' or ');
                                  echo Html::a($settings->email, "mailto:$settings->email");
                              }
                          }
                      ?>
                  </p>
<!--                  <p class="hidden-md hidden-lg hidden-xs hidden-sm">-->
<!--                    <a href="#" data-animate-hover="pulse"><i class="fa fa-phone"></i></a>-->
<!--                    <a href="#" data-animate-hover="pulse"><i class="fa fa-envelope"></i></a>-->
<!--                  </p>-->
                </div>
                <div class="col-xs-7">
                  <div class="social">
                      <?php
                          if (!empty($settings->facebook)) {
                              echo Html::a(
                                  Html::icon(
                                      'facebook',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->facebook,
                                  [
                                      'class' => 'external facebook',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->vk)) {
                              echo Html::a(
                                  Html::icon(
                                      'vk',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->vk,
                                  [
                                      'class' => 'external vk',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->google)) {
                              echo Html::a(
                                  Html::icon(
                                      'google-plus',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->google,
                                  [
                                      'class' => 'external gplus',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->twitter)) {
                              echo Html::a(
                                  Html::icon(
                                      'twitter',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->twitter,
                                  [
                                      'class' => 'external twitter',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->ok)) {
                              echo Html::a(
                                  Html::icon(
                                      'odnoklassniki',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->ok,
                                  [
                                      'class' => 'external odnoklassniki',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
<!--                      --><?php
//                          if (!empty($settings->email)) {
//                              echo Html::a(
//                                  Html::icon(
//                                      'envelope',
//                                      [
//                                          'prefix' => 'fa fa-',
//                                      ]
//                                  ),
//                                  "mailto:$settings->email",
//                                  [
//                                      'class' => 'email',
//                                      'data'  => [
//                                          'animate-hover' => 'pulse',
//                                      ],
//                                  ]
//                              );
//                          }
//                      ?>
                      
                      <?= LanguageWidget::widget() ?>
                  
                  </div>
                </div>
              </div>
            </div>
          </div>
          <!-- *** TOP END *** -->
          
          <!-- *** NAVBAR ***
  _________________________________________________________ -->
          <div class="navbar-affixed-top" data-spy="affix" data-offset-top="200">
            
            <div class="navbar navbar-default yamm" role="navigation" id="navbar">
              
              <div class="container">
                <div class="navbar-header">
                  
                  <a class="navbar-brand home" href="<?php echo Url::home(); ?>">
                      <?php
                          echo ImageHelper::set($logo)
                                          ->setHeight(42)
                                          ->renderImage(
                                              [
                                                  'alt' => $settings->name,
                                              ]
                                          )
                      ?>
                  </a>
                  <div class="navbar-buttons">
                    <button type="button" class="navbar-toggle btn-template-main" data-toggle="collapse" data-target="#navigation">
                      <span class="sr-only">Toggle navigation</span>
                      <i class="fa fa-align-justify"></i>
                    </button>
                  </div>
                </div>
                
                <div class="navbar-collapse collapse" id="navigation">
                    <?php
                        $items = [];
                        $items[] = [
                            'label' => \Yii::t('app', 'Home'),
                            'url'   => [ 'site/index' ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'News'),
                            'url'   => [ 'blog/index' ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'About'),
                            'url'   => [ 'site/about' ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'Events'),
                            'url'   => [ 'event/index' ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'Media'),
                            'url'   => [ 'gallery/index' ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'Contacts'),
                            'url'   => [ 'site/contact' ],
                        ];
                        foreach ($pageCategories as $category) {
                            
                            if (empty($category->pages)) {
                                continue;
                            }
                            $pages = [];
                            foreach ($category->pages as $page) {
                                $pages[] = [
                                    'label' => $page->title,
                                    'url'   => Url::to([ 'alias' => $page->alias ]),
                                ];
                            }
                            $items[] = [
                                'label' => $category->title,
                                'items' => $pages,
                            ];
                        }
                        
                        
                        
                       
                        echo Nav::widget(
                            [
                                'items'   => $items,
                                'options' => [
                                    'class' => 'nav navbar-nav navbar-right',
                                ],
                            ]
                        );
                    ?>
                </div>
                
                
                <div class="collapse clearfix" id="search">
                  
                  <form class="navbar-form" role="search">
                    <div class="input-group">
                      <input type="text" class="form-control" placeholder="Search">
                      <span class="input-group-btn">

                    <button type="submit" class="btn btn-template-main"><i class="fa fa-search"></i></button>

                </span>
                    </div>
                  </form>
                
                </div>
                <!--/.nav-collapse -->
              
              </div>
            
            
            </div>
            <!-- /#navbar -->
          
          </div>
          
          <!-- *** NAVBAR END *** -->
        
        </header>
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
          <?php
              ArtboxModalWidget::begin(
                  [
                      'modalTagOptions' => [
                          'id' => 'feedback-modal',
                      ],
                  ]
              );
              
              $module->renderForm($this);
              
              ArtboxModalWidget::end();
          ?>
        
        <!-- *** FeedBack MODAL END *** -->
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
        <div class="success_" id="success-modal" aria-labelledby="Success" aria-hidden="true">
          <div class="forms_wr_">
            <div class="modal-header">
              <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times</button>
                <h3 class="modal-title" id="Success"><?= \Yii::t('app', 'Form sends success Header'); ?></h3>
            </div>
            <div class="modal-body">
    
                <p><?= \Yii::t('app', 'Form sends success') ?></p>
              <p class="text-center">
                  <button type="button" class="btn btn-template-primary" data-dismiss="modal"><?= \Yii::t(
                          'app',
                          'Close'
                      ); ?></button>
              </p>
            </div>
          </div>
        </div>
        
        <!-- *** FeedBack MODAL END *** -->
        
        <!-- *** Breadcrumbs *** -->
          <?php
              if (!$isHome) {
                  ?>
                <div id="heading-breadcrumbs">
                  <div class="container">
                    <div class="row">
                      <div class="col-md-7">
                        <h1><?= $seo->h1 ?></h1>
                      </div>
                      <div class="col-md-5">
                          <?= Breadcrumbs::widget(
                              [
                                  'links' => isset($this->params[ 'breadcrumbs' ]) ? $this->params[ 'breadcrumbs' ] : [],
                                  'homeLink'=>
                                [
                                   'label'=>\Yii::t('app','Home'),
                                   'url'=> Url::home()
                                ]
                              ]
                          ) ?>
                      
                      </div>
                    </div>
                  </div>
                </div>
                  <?php
              }
          ?>
        <!-- *** Breadcrumbs END *** -->
          
          <?= $content ?>
        
        <!-- *** FOOTER ***
_________________________________________________________ -->
        
        <footer id="footer">
          <div class="container">
            <div class="col-md-6 col-sm-12">

            </div>
            
            <div class="col-md-4 col-sm-12 col-md-offset-2">
              
              <h4><?php echo \Yii::t('app', 'Contacts'); ?></h4>
              
              <p>
                  <?php
                      if (!empty($settings->lang->address)) {
                          echo Html::tag('strong', $settings->lang->address);
                      }
                  ?>
              </p>
                
                <?= Html::a(
                    \Yii::t('app', 'Go to contact page'),
                    [ 'site/contact' ],
                    [
                        'class' => 'btn btn-small btn-template-transparent-primary',
                    ]
                ) ?>
              
              <hr class="hidden-md hidden-lg hidden-sm">
            
            </div>
            
            <div class="col-md-12">
              <p class="pull-left">&copy; <?= date('Y') ?>. <?= $settings->name; ?></p>
            </div>
          </div>
          <!-- /.container -->
        </footer>
        <!-- /#footer -->
        
        <!-- *** FOOTER END *** -->

        <span id="back-to-top" title="Back to top"></span>
      
      </div>
      <div id="overlay" style="display:none;"></div>
      <!-- /#all -->
        <?php $this->endBody() ?>
    </body>
  </html>
<?php $this->endPage() ?>